Mirror of the gdb-patches mailing list
 help / color / mirror / Atom feed
* [PATCH] [gdb] More codespell fixes
@ 2026-06-15 15:23 Tom de Vries
  2026-07-13 13:23 ` Tom de Vries
  0 siblings, 1 reply; 2+ messages in thread
From: Tom de Vries @ 2026-06-15 15:23 UTC (permalink / raw)
  To: gdb-patches

I did this in gdb/pyproject.toml:
...
+regex = "[a-zA-Z0-9\\-']+"
...
allowing us to detect things like 'gcs_availabe':
...
$ echo gcs_availabe | codespell --regex="[a-zA-Z0-9\-']+" -
1: gcs_availabe
	availabe ==> available
...
and ran:
...
$ codespell --toml gdb/pyproject.toml gdb*
...
and manually fixed fallout.

This fixes the following typos:
...
  typdef -> typedef
  bloc -> block
  reenables -> re-enables
  overlayed -> overlaid
  advertized -> advertised
  stript -> script
  reenable -> re-enable
  interruptable -> interruptible
  restire -> restore
  sufix -> suffix
  regisers -> registers
  constrait -> constraint
  attriute -> attribute
  followin -> following
  immedate -> immediate
  constrol -> control
  sting -> string
  vesion -> version
  operatons -> operations
  inheritence -> inheritance
  decsription -> description
  hilighted -> highlighted
  enque -> enqueue
  ouputs -> outputs
...

The "vesion -> version" fix in gdb.dwarf2/dw2-entry-pc.exp allowed a bit of
cleanup.

Tested on x86_64-linux and aarch64-linux.

Bug: https://sourceware.org/bugzilla/show_bug.cgi?id=34241
---
 gdb/ada-lang.c                                     |  4 ++--
 gdb/ada-tasks.c                                    |  2 +-
 gdb/c-typeprint.c                                  |  2 +-
 gdb/findvar.c                                      |  8 ++++----
 gdb/go32-nat.c                                     |  6 +++---
 gdb/guile/guile-internal.h                         |  2 +-
 gdb/infrun.c                                       |  4 ++--
 gdb/minsyms.c                                      |  2 +-
 gdb/python/lib/gdb/dap/server.py                   |  4 ++--
 gdb/python/python.c                                |  4 ++--
 gdb/rs6000-tdep.c                                  |  2 +-
 gdb/stubs/m68k-stub.c                              |  4 ++--
 gdb/symfile.c                                      |  6 +++---
 gdb/symfile.h                                      |  2 +-
 gdb/symtab.h                                       |  2 +-
 gdb/testsuite/README                               |  2 +-
 gdb/testsuite/gdb.ada/catch_ex.exp                 |  2 +-
 gdb/testsuite/gdb.ada/mi_catch_ex.exp              |  2 +-
 gdb/testsuite/gdb.base/dup-sect.exp                |  2 +-
 gdb/testsuite/gdb.base/foll-fork-syscall.exp       |  2 +-
 gdb/testsuite/gdb.disasm/hppa.exp                  |  8 ++++----
 gdb/testsuite/gdb.dwarf2/dw2-double-set-die-type.S |  2 +-
 gdb/testsuite/gdb.dwarf2/dw2-entry-pc.exp          | 11 ++++++-----
 gdb/testsuite/gdb.mi/mi-basics.exp                 |  4 ++--
 gdb/testsuite/gdb.mi/mi-var-rtti.cc                | 10 +++++-----
 gdb/testsuite/gdb.mi/mi-var-rtti.exp               |  2 +-
 gdb/testsuite/gdb.python/py-explore.exp            |  4 ++--
 gdb/tui/tui-regs.c                                 |  4 ++--
 gdbserver/notif.cc                                 |  4 ++--
 gdbserver/notif.h                                  |  2 +-
 gdbserver/server.cc                                |  4 ++--
 31 files changed, 60 insertions(+), 59 deletions(-)

diff --git a/gdb/ada-tasks.c b/gdb/ada-tasks.c
index f55afcc915d..6a91bf1953c 100644
--- a/gdb/ada-tasks.c
+++ b/gdb/ada-tasks.c
@@ -554,7 +554,7 @@ ada_get_tcb_types_info (void)
   /* Get the type for Ada_Task_Control_Block.Common.  */
   common_type = common_atcb_sym->type ();
 
-  /* Get the type for Ada_Task_Control_Bloc.Common.Call.LL.  */
+  /* Get the type for Ada_Task_Control_Block.Common.Call.LL.  */
   ll_type = private_data_sym->type ();
 
   /* Get the type for Common_ATCB.Call.all.  */
diff --git a/gdb/c-typeprint.c b/gdb/c-typeprint.c
index e418aca56a4..aaace85aa29 100644
--- a/gdb/c-typeprint.c
+++ b/gdb/c-typeprint.c
@@ -870,7 +870,7 @@ output_access_specifier (struct ui_file *stream,
 }
 
 /* Helper function that temporarily disables FLAGS->PRINT_OFFSETS,
-   calls 'c_print_type_1', and then reenables FLAGS->PRINT_OFFSETS if
+   calls 'c_print_type_1', and then re-enables FLAGS->PRINT_OFFSETS if
    applicable.  */
 
 static void
diff --git a/gdb/findvar.c b/gdb/findvar.c
index 98351143e79..daa4730eb4d 100644
--- a/gdb/findvar.c
+++ b/gdb/findvar.c
@@ -338,7 +338,7 @@ language_defn::read_var_value (struct symbol *var,
 	if (overlay_debugging)
 	  {
 	    struct objfile *var_objfile = var->objfile ();
-	    addr = symbol_overlayed_address (var->value_address (),
+	    addr = symbol_overlaid_address (var->value_address (),
 					     var->obj_section (var_objfile));
 	  }
 	else
@@ -378,7 +378,7 @@ language_defn::read_var_value (struct symbol *var,
     case LOC_STATIC:
       if (overlay_debugging)
 	addr
-	  = symbol_overlayed_address (var->value_address (),
+	  = symbol_overlaid_address (var->value_address (),
 				      var->obj_section (var->objfile ()));
       else
 	addr = var->value_address ();
@@ -419,7 +419,7 @@ language_defn::read_var_value (struct symbol *var,
 
     case LOC_BLOCK:
       if (overlay_debugging)
-	addr = symbol_overlayed_address
+	addr = symbol_overlaid_address
 	  (var->value_block ()->entry_pc (),
 	   var->obj_section (var->objfile ()));
       else
@@ -483,7 +483,7 @@ language_defn::read_var_value (struct symbol *var,
 	else
 	  addr = bmsym.value_address ();
 	if (overlay_debugging)
-	  addr = symbol_overlayed_address (addr, obj_section);
+	  addr = symbol_overlaid_address (addr, obj_section);
 	/* Determine address of TLS variable. */
 	if (obj_section
 	    && (obj_section->the_bfd_section->flags & SEC_THREAD_LOCAL) != 0)
diff --git a/gdb/go32-nat.c b/gdb/go32-nat.c
index b3ea5c1fd5c..fd8f46f1b6e 100644
--- a/gdb/go32-nat.c
+++ b/gdb/go32-nat.c
@@ -1073,7 +1073,7 @@ go32_sysinfo (const char *arg, int from_tty)
   char cpuid_vendor[13];
   unsigned cpuid_max = 0, cpuid_eax, cpuid_ebx, cpuid_ecx, cpuid_edx;
   unsigned true_dos_version = _get_dos_version (1);
-  unsigned advertized_dos_version = ((unsigned int)_osmajor << 8) | _osminor;
+  unsigned advertised_dos_version = ((unsigned int)_osmajor << 8) | _osminor;
   int dpmi_flags;
   char dpmi_vendor_info[129];
   int dpmi_vendor_available;
@@ -1280,7 +1280,7 @@ go32_sysinfo (const char *arg, int from_tty)
   gdb_puts ("\n");
   gdb_printf ("DOS Version....................%s %s.%s",
 	      _os_flavor, u.release, u.version);
-  if (true_dos_version != advertized_dos_version)
+  if (true_dos_version != advertised_dos_version)
     gdb_printf (" (disguised as v%d.%d)", _osmajor, _osminor);
   gdb_puts ("\n");
   if (!windows_major)
@@ -1322,7 +1322,7 @@ go32_sysinfo (const char *arg, int from_tty)
 	}
       gdb_printf ("%s)\n", windows_flavor);
     }
-  else if (true_dos_version == 0x532 && advertized_dos_version == 0x500)
+  else if (true_dos_version == 0x532 && advertised_dos_version == 0x500)
     gdb_printf ("Windows Version................"
 		"Windows NT family (W2K/XP/W2K3/Vista/W2K8)\n");
   gdb_puts ("\n");
diff --git a/gdb/guile/guile-internal.h b/gdb/guile/guile-internal.h
index a86ad48eb12..95545b43e86 100644
--- a/gdb/guile/guile-internal.h
+++ b/gdb/guile/guile-internal.h
@@ -594,7 +594,7 @@ extern struct value *vlscm_convert_value_from_scheme
   (const char *func_name, int obj_arg_pos, SCM obj, SCM *except_scmp,
    struct gdbarch *gdbarch, const struct language_defn *language);
 \f
-/* stript_lang methods */
+/* script_lang methods */
 
 extern objfile_script_sourcer_func gdbscm_source_objfile_script;
 extern objfile_script_executor_func gdbscm_execute_objfile_script;
diff --git a/gdb/infrun.c b/gdb/infrun.c
index 00bedc7b6ae..2448d2412da 100644
--- a/gdb/infrun.c
+++ b/gdb/infrun.c
@@ -5738,7 +5738,7 @@ handle_one (const wait_one_event &event)
    the expected stops.  */
 
 static void
-reenable_target_async ()
+re_enable_target_async ()
 {
   for (inferior *inf : all_inferiors ())
     {
@@ -5882,7 +5882,7 @@ stop_all_threads (const char *reason, inferior *inf)
 	  if (pass > 0)
 	    pass = -1;
 
-	  reenable_target_async ();
+	  re_enable_target_async ();
 
 	  for (int i = 0; i < waits_needed; i++)
 	    {
diff --git a/gdb/minsyms.c b/gdb/minsyms.c
index 4eafc789047..ad63e9d5eaf 100644
--- a/gdb/minsyms.c
+++ b/gdb/minsyms.c
@@ -1618,7 +1618,7 @@ find_minsym_type_and_address (minimal_symbol *msymbol,
     addr = bound_msym.value_address ();
 
   if (overlay_debugging)
-    addr = symbol_overlayed_address (addr, section);
+    addr = symbol_overlaid_address (addr, section);
 
   if (is_tls)
     {
diff --git a/gdb/python/lib/gdb/dap/server.py b/gdb/python/lib/gdb/dap/server.py
index d94036e03e5..04b3c4de0de 100644
--- a/gdb/python/lib/gdb/dap/server.py
+++ b/gdb/python/lib/gdb/dap/server.py
@@ -213,7 +213,7 @@ class CancellationHandler:
                 heapq.heappush(self._reqs, req)
 
     @contextmanager
-    def interruptable_region(self, req):
+    def interruptible_region(self, req):
         """Return a new context manager that sets in_flight_gdb_thread to
         REQ."""
         if req is None:
@@ -672,7 +672,7 @@ class Cancellable(object):
     @in_gdb_thread
     def __call__(self):
         try:
-            with _server.canceller.interruptable_region(self.req):
+            with _server.canceller.interruptible_region(self.req):
                 val = self._fn()
                 if self._result_q is not None:
                     self._result_q.put(val)
diff --git a/gdb/python/python.c b/gdb/python/python.c
index 2131c4a0648..214abd03905 100644
--- a/gdb/python/python.c
+++ b/gdb/python/python.c
@@ -1824,7 +1824,7 @@ gdbpy_source_objfile_script (const struct extension_language_defn *extlang,
     return;
 
   gdbpy_enter enter_py (objfile->arch ());
-  scoped_restore restire_current_objfile
+  scoped_restore restore_current_objfile
     = make_scoped_restore (&gdbpy_current_objfile, objfile);
 
   int result = python_run_simple_file (file, filename);
@@ -1847,7 +1847,7 @@ gdbpy_execute_objfile_script (const struct extension_language_defn *extlang,
     return;
 
   gdbpy_enter enter_py (objfile->arch ());
-  scoped_restore restire_current_objfile
+  scoped_restore restore_current_objfile
     = make_scoped_restore (&gdbpy_current_objfile, objfile);
 
   int ret = eval_python_command (script, Py_file_input);
diff --git a/gdb/rs6000-tdep.c b/gdb/rs6000-tdep.c
index e135df94a40..fc8658f5aa5 100644
--- a/gdb/rs6000-tdep.c
+++ b/gdb/rs6000-tdep.c
@@ -4182,7 +4182,7 @@ bfd_uses_spe_extensions (bfd *abfd)
 #define P_PPC_D(insn_prefix, insn_suffix) \
   PPC_SEXT (PPC_FIELD (insn_prefix, 14, 18) << 16 \
 	    | PPC_FIELD (insn_suffix, 16, 16), 34)
-#define P_PPC_TX5(insn_sufix)	PPC_BIT (insn_suffix, 5)
+#define P_PPC_TX5(insn_suffix)	PPC_BIT (insn_suffix, 5)
 #define P_PPC_TX15(insn_suffix) PPC_BIT (insn_suffix, 15)
 #define P_PPC_XT(insn_suffix)	((PPC_TX (insn_suffix) << 5) \
 				 | PPC_T (insn_suffix))
diff --git a/gdb/stubs/m68k-stub.c b/gdb/stubs/m68k-stub.c
index c63eee7d2c9..4e54bec971e 100644
--- a/gdb/stubs/m68k-stub.c
+++ b/gdb/stubs/m68k-stub.c
@@ -330,7 +330,7 @@ asm("
 	movew   sp@,d1          /* get status register          */
 	movew   d1,a5@(66)      /* save sr		 	*/
 	movel   sp@(2),a4       /* save pc in a4 for later use  */
-	movel   a4,a5@(68)      /* save pc in _regisers[]      	*/
+	movel   a4,a5@(68)      /* save pc in _registers[]      	*/
 
 #
 # figure out how many bytes in the stack frame
@@ -430,7 +430,7 @@ asm("
 	movew   sp@+,d1         /* pop status register          */
 	movel   sp@+,a4         /* pop program counter          */
 	movew   d1,a5@(66)      /* save sr		 	*/
-	movel   a4,a5@(68)      /* save pc in _regisers[]      	*/
+	movel   a4,a5@(68)      /* save pc in _registers[]      	*/
 	movel   a4,a0@-         /* copy pc to frame buffer      */
 	movew   d1,a0@-         /* copy sr to frame buffer      */
 
diff --git a/gdb/symfile.c b/gdb/symfile.c
index 5f046a03567..ce6c429c0d0 100644
--- a/gdb/symfile.c
+++ b/gdb/symfile.c
@@ -2923,7 +2923,7 @@ clear_symtab_users (symfile_add_flags add_flags)
    sections_overlap(sec1, sec2):  true if mapped sec1 and sec2 ranges overlap
    overlay_mapped_address(...):   map an address from section's LMA to VMA
    overlay_unmapped_address(...): map an address from section's VMA to LMA
-   symbol_overlayed_address(...): Return a "current" address for symbol:
+   symbol_overlaid_address(...): Return a "current" address for symbol:
    either in VMA or LMA depending on whether
    the symbol's section is currently mapped.  */
 
@@ -3092,12 +3092,12 @@ overlay_mapped_address (CORE_ADDR pc, struct obj_section *section)
   return pc;
 }
 
-/* Function: symbol_overlayed_address
+/* Function: symbol_overlaid_address
    Return one of two addresses (relative to the VMA or to the LMA),
    depending on whether the section is mapped or not.  */
 
 CORE_ADDR
-symbol_overlayed_address (CORE_ADDR address, struct obj_section *section)
+symbol_overlaid_address (CORE_ADDR address, struct obj_section *section)
 {
   if (overlay_debugging)
     {
diff --git a/gdb/symfile.h b/gdb/symfile.h
index 770bd291ab1..0aed0f4db4d 100644
--- a/gdb/symfile.h
+++ b/gdb/symfile.h
@@ -301,7 +301,7 @@ extern CORE_ADDR overlay_mapped_address (CORE_ADDR, struct obj_section *);
 extern CORE_ADDR overlay_unmapped_address (CORE_ADDR, struct obj_section *);
 
 /* Convert an address in an overlay section (force into VMA range).  */
-extern CORE_ADDR symbol_overlayed_address (CORE_ADDR, struct obj_section *);
+extern CORE_ADDR symbol_overlaid_address (CORE_ADDR, struct obj_section *);
 
 /* Load symbols from a file.  */
 extern void symbol_file_add_main (const char *args,
diff --git a/gdb/symtab.h b/gdb/symtab.h
index b29b72aba00..0fdd59844c3 100644
--- a/gdb/symtab.h
+++ b/gdb/symtab.h
@@ -620,7 +620,7 @@ struct general_symbol_info
   struct obj_section *obj_section (const struct objfile *objfile) const;
 };
 
-extern CORE_ADDR symbol_overlayed_address (CORE_ADDR, struct obj_section *);
+extern CORE_ADDR symbol_overlaid_address (CORE_ADDR, struct obj_section *);
 
 /* Try to determine the demangled name for a symbol, based on the
    language of that symbol.  If the language is set to language_auto,
diff --git a/gdb/testsuite/README b/gdb/testsuite/README
index 479e81f90f5..f354144b872 100644
--- a/gdb/testsuite/README
+++ b/gdb/testsuite/README
@@ -81,7 +81,7 @@ iterations will be run.
 
 After running the tests, you shall see a file name 'racy.sum' in the
 gdb/testsuite directory.  You can also inspect the generated *.log and
-*.sum files by looking into the gdb/testsuite/racy_ouputs directory.
+*.sum files by looking into the gdb/testsuite/racy_outputs directory.
 
 If you already have *.sum files generated from previous testsuite runs
 and you would like to analyze them without having to run the testsuite
diff --git a/gdb/testsuite/gdb.ada/catch_ex.exp b/gdb/testsuite/gdb.ada/catch_ex.exp
index dd482561a9c..dcdebeca3e4 100644
--- a/gdb/testsuite/gdb.ada/catch_ex.exp
+++ b/gdb/testsuite/gdb.ada/catch_ex.exp
@@ -75,7 +75,7 @@ gdb_test "continue" \
 #    We'll catch unhandled exceptions
 #  - continue, we should see the first Program_Error exception
 #  - continue, we should see the failed assertion
-#  - continue, we should see the unhandled Constrait_Error exception
+#  - continue, we should see the unhandled Constraint_Error exception
 #  - continue, the program exits.
 
 if {![runto_main]} {
diff --git a/gdb/testsuite/gdb.ada/mi_catch_ex.exp b/gdb/testsuite/gdb.ada/mi_catch_ex.exp
index 3a88881a321..bf8ee29435b 100644
--- a/gdb/testsuite/gdb.ada/mi_catch_ex.exp
+++ b/gdb/testsuite/gdb.ada/mi_catch_ex.exp
@@ -90,7 +90,7 @@ continue_to_exception \
 #    We'll catch unhandled exceptions
 #  - continue, we should see the first Program_Error exception
 #  - continue, we should see the failed assertion
-#  - continue, we should see the unhandled Constrait_Error exception
+#  - continue, we should see the unhandled Constraint_Error exception
 #  - continue, the program exits.
 
 with_test_prefix "scenario 2" {
diff --git a/gdb/testsuite/gdb.base/dup-sect.exp b/gdb/testsuite/gdb.base/dup-sect.exp
index d89f5fa1956..f341456e00e 100644
--- a/gdb/testsuite/gdb.base/dup-sect.exp
+++ b/gdb/testsuite/gdb.base/dup-sect.exp
@@ -19,7 +19,7 @@
 # When kept in object file (before final executable link) it still works.
 # When separate debug info file is not used it still works.
 # When the ELF symbol table is kept in the main binary it still works.
-# Used .S file as in .c file we would need __attriute__((section)) which is
+# Used .S file as in .c file we would need __attribute__((section)) which is
 # a GCC extension.
 
 # This test can only be run on targets which support ELF and use gas.
diff --git a/gdb/testsuite/gdb.base/foll-fork-syscall.exp b/gdb/testsuite/gdb.base/foll-fork-syscall.exp
index 0452d403c62..bbda7aba6e2 100644
--- a/gdb/testsuite/gdb.base/foll-fork-syscall.exp
+++ b/gdb/testsuite/gdb.base/foll-fork-syscall.exp
@@ -97,7 +97,7 @@ proc_with_prefix test_catch_syscall {follow-fork-mode detach-on-fork} {
     if {${follow-fork-mode} == "parent"} {
 	set following_inf 1
     } else {
-	set followin_inf 2
+	set following_inf 2
     }
     # Next stop should be the fork catchpoint.
     set expected_re ""
diff --git a/gdb/testsuite/gdb.disasm/hppa.exp b/gdb/testsuite/gdb.disasm/hppa.exp
index 9881a3d6544..c8e27614cee 100644
--- a/gdb/testsuite/gdb.disasm/hppa.exp
+++ b/gdb/testsuite/gdb.disasm/hppa.exp
@@ -142,9 +142,9 @@ proc all_immediate_tests { } {
 .*ldo 5\\(r26\\),r26.*
 .*ldil -21524800,r26.*
 .*addil -21524800,r5.*
-.*$gdb_prompt $" { pass "immedate_tests" }
-	-re "$gdb_prompt $" { fail "immedate_tests" }
-	timeout { fail "(timeout) immedate_tests " }
+.*$gdb_prompt $" { pass "immediate_tests" }
+	-re "$gdb_prompt $" { fail "immediate_tests" }
+	timeout { fail "(timeout) immediate_tests " }
     }
 }
 
@@ -849,7 +849,7 @@ proc all_system_control_tests { } {
 .*sync.*
 .*syncdma.*
 .*diag 4d2.*
-.*$gdb_prompt $" { pass "system_constrol_tests" }
+.*$gdb_prompt $" { pass "system_control_tests" }
 	-re "$gdb_prompt $" { fail "system_control_tests" }
 	timeout { file "(timeout) system_control_tests" }
     }
diff --git a/gdb/testsuite/gdb.dwarf2/dw2-double-set-die-type.S b/gdb/testsuite/gdb.dwarf2/dw2-double-set-die-type.S
index 360fb158242..d5d98be01f2 100644
--- a/gdb/testsuite/gdb.dwarf2/dw2-double-set-die-type.S
+++ b/gdb/testsuite/gdb.dwarf2/dw2-double-set-die-type.S
@@ -346,7 +346,7 @@
 	.uleb128 0x13	/* (DW_AT_language) */
 	.uleb128 0xb	/* (DW_FORM_data1) */
 	.uleb128 0x3	/* (DW_AT_name) */
-	.uleb128 0x8	/* (DW_FORM_sting) */
+	.uleb128 0x8	/* (DW_FORM_string) */
 	.byte	0x0
 	.byte	0x0
 
diff --git a/gdb/testsuite/gdb.dwarf2/dw2-entry-pc.exp b/gdb/testsuite/gdb.dwarf2/dw2-entry-pc.exp
index d386614edb5..193c26bb65d 100644
--- a/gdb/testsuite/gdb.dwarf2/dw2-entry-pc.exp
+++ b/gdb/testsuite/gdb.dwarf2/dw2-entry-pc.exp
@@ -143,17 +143,18 @@ proc build_and_test_ranged { suffix asm_file entry_pc } {
 # the entry_pc attribute is not given.  The function's entry PC will
 # default to the low address.
 
-proc_with_prefix use_low_high_bounds_without_entry_pc { dwarf_vesion } {
+proc_with_prefix use_low_high_bounds_without_entry_pc { dwarf_version } {
     set suffix [get_next_suffix]
 
     # Make some DWARF for the test.
     set asm_file [standard_output_file "$::testfile-dw-$suffix.S"]
     Dwarf::assemble $asm_file {
+	upvar dwarf_version dwarf_version
 	global srcfile
 
 	declare_labels lines_table
 
-	cu { version $::dwarf_version } {
+	cu { version $dwarf_version } {
 	    compile_unit {
 		DW_AT_producer "gcc"
 		DW_AT_language @DW_LANG_C
@@ -287,7 +288,7 @@ proc_with_prefix use_ranges_without_entry_pc { dwarf_version } {
 
 	declare_labels lines_table ranges_label
 
-	cu { version $::dwarf_version } {
+	cu { version $dwarf_version } {
 	    compile_unit {
 		DW_AT_producer "gcc"
 		DW_AT_language @DW_LANG_C
@@ -351,7 +352,7 @@ proc_with_prefix use_ranges_with_entry_pc { dwarf_version } {
 
 	declare_labels lines_table ranges_label
 
-	cu { version $::dwarf_version } {
+	cu { version $dwarf_version } {
 	    compile_unit {
 		DW_AT_producer "gcc"
 		DW_AT_language @DW_LANG_C
@@ -418,7 +419,7 @@ proc_with_prefix use_ranges_with_entry_offset { dwarf_version } {
 
 	set foo_offset [expr {$::foo_middle_addr - $::r1_s}]
 
-	cu { version $::dwarf_version } {
+	cu { version $dwarf_version } {
 	    compile_unit {
 		DW_AT_producer "gcc"
 		DW_AT_language @DW_LANG_C
diff --git a/gdb/testsuite/gdb.mi/mi-basics.exp b/gdb/testsuite/gdb.mi/mi-basics.exp
index 8f18f41af04..a48b8521f5a 100644
--- a/gdb/testsuite/gdb.mi/mi-basics.exp
+++ b/gdb/testsuite/gdb.mi/mi-basics.exp
@@ -69,7 +69,7 @@ proc test_mi_interpreter_selection {} {
     return 0
 }
 
-proc test_exec_and_symbol_mi_operatons {} {
+proc test_exec_and_symbol_mi_operations {} {
     global mi_gdb_prompt
     global binfile testfile
 
@@ -261,7 +261,7 @@ proc test_setshow_inferior_tty {} {
 }
 
 if { [test_mi_interpreter_selection]
-      && [test_exec_and_symbol_mi_operatons] } {
+      && [test_exec_and_symbol_mi_operations] } {
   test_breakpoints_deletion
   test_dir_specification
   test_cwd_specification
diff --git a/gdb/testsuite/gdb.mi/mi-var-rtti.cc b/gdb/testsuite/gdb.mi/mi-var-rtti.cc
index bde28ebaeda..26f1f93ad0c 100644
--- a/gdb/testsuite/gdb.mi/mi-var-rtti.cc
+++ b/gdb/testsuite/gdb.mi/mi-var-rtti.cc
@@ -193,14 +193,14 @@ struct MultipleDerived : public First, Base {
 };
 
 
-void use_rtti_with_multiple_inheritence_test ()
+void use_rtti_with_multiple_inheritance_test ()
 {
-  /*: BEGIN: use_rtti_with_multiple_inheritence :*/
+  /*: BEGIN: use_rtti_with_multiple_inheritance :*/
 	MultipleDerived d;
 	Base* ptr = &d;
 	Base& ref = d;
   /*:
-	set testname use_rtti_with_multiple_inheritence
+	set testname use_rtti_with_multiple_inheritance
 	set_print_object off $testname
 	check_new_derived_without_rtti ptr {Base \*} $testname
 	check_new_derived_without_rtti ref {Base \&} $testname
@@ -234,7 +234,7 @@ void use_rtti_with_multiple_inheritence_test ()
 	    "delete varobj for ptr (with RTTI) in $testname"
   :*/
 	return;
-  /*: END: use_rtti_with_multiple_inheritence :*/
+  /*: END: use_rtti_with_multiple_inheritance :*/
 }
 
 
@@ -362,7 +362,7 @@ int main ()
 	use_rtti_for_ref_test();
 	use_rtti_for_ptr_child_test();
 	use_rtti_for_ref_child_test();
-	use_rtti_with_multiple_inheritence_test();
+	use_rtti_with_multiple_inheritance_test();
 	type_update_when_use_rtti_test();
 	skip_type_update_when_not_use_rtti_test();
 	return 0;
diff --git a/gdb/testsuite/gdb.mi/mi-var-rtti.exp b/gdb/testsuite/gdb.mi/mi-var-rtti.exp
index 4a1bee241f9..640d1ca71f3 100644
--- a/gdb/testsuite/gdb.mi/mi-var-rtti.exp
+++ b/gdb/testsuite/gdb.mi/mi-var-rtti.exp
@@ -111,7 +111,7 @@ set inline_tests {
     use_rtti_for_ref
     use_rtti_for_ptr_child
     use_rtti_for_ref_child
-    use_rtti_with_multiple_inheritence
+    use_rtti_with_multiple_inheritance
     type_update_when_use_rtti
     skip_type_update_when_not_use_rtti
 }
diff --git a/gdb/testsuite/gdb.python/py-explore.exp b/gdb/testsuite/gdb.python/py-explore.exp
index debe3031535..d3a25a5df33 100644
--- a/gdb/testsuite/gdb.python/py-explore.exp
+++ b/gdb/testsuite/gdb.python/py-explore.exp
@@ -220,7 +220,7 @@ gdb_test_multiple "explore cu" "" {
 # Type exploration tests
 ########################
 
-proc scalar_type_decsription {type} {
+proc scalar_type_description {type} {
     return "'$type' is a scalar type\."
 }
 
@@ -258,7 +258,7 @@ set CU_field_0 "field 's' of 'union ComplexUnion'"
 set CU_field_1 "field 'sa' of 'union ComplexUnion'"
 set CU_field_1_array_element "an array element of $CU_field_1"
 
-gdb_test "explore int" ".*[scalar_type_decsription {int}].*"
+gdb_test "explore int" ".*[scalar_type_description {int}].*"
 
 gdb_test_multiple "explore struct SimpleStruct" "" {
     -re ".*[compound_type_description $SS {struct/class}].*$SS_fields_types.*" {
diff --git a/gdb/tui/tui-regs.c b/gdb/tui/tui-regs.c
index 3e2e0745993..20ab8444b44 100644
--- a/gdb/tui/tui-regs.c
+++ b/gdb/tui/tui-regs.c
@@ -361,11 +361,11 @@ tui_data_window::check_register_values (const frame_info_ptr &frame)
     {
       for (tui_register_info &data_item_win : m_regs_content)
 	{
-	  bool was_hilighted = data_item_win.highlighted ();
+	  bool was_highlighted = data_item_win.highlighted ();
 
 	  data_item_win.update (frame);
 
-	  if ((data_item_win.highlighted () || was_hilighted)
+	  if ((data_item_win.highlighted () || was_highlighted)
 	      && data_item_win.visible ())
 	    data_item_win.rerender (handle.get (), m_item_width);
 	}
diff --git a/gdbserver/notif.cc b/gdbserver/notif.cc
index 4a2b12b8147..1745a96a051 100644
--- a/gdbserver/notif.cc
+++ b/gdbserver/notif.cc
@@ -115,7 +115,7 @@ handle_notif_ack (char *own_buf, int packet_len)
 /* Put EVENT to the queue of NOTIF.  */
 
 void
-notif_event_enque (struct notif_server *notif,
+notif_event_enqueue (struct notif_server *notif,
 		   struct notif_event *event)
 {
   notif->queue.push_back (event);
@@ -133,7 +133,7 @@ notif_push (struct notif_server *np, struct notif_event *new_event)
   bool is_first_event = np->queue.empty ();
 
   /* Something interesting.  Tell GDB about it.  */
-  notif_event_enque (np, new_event);
+  notif_event_enqueue (np, new_event);
 
   /* If this is the first stop reply in the queue, then inform GDB
      about it, by sending a corresponding notification.  */
diff --git a/gdbserver/notif.h b/gdbserver/notif.h
index dc3164e91cd..76fb8392640 100644
--- a/gdbserver/notif.h
+++ b/gdbserver/notif.h
@@ -62,7 +62,7 @@ int handle_notif_ack (char *own_buf, int packet_len);
 void notif_write_event (struct notif_server *notif, char *own_buf);
 
 void notif_push (struct notif_server *np, struct notif_event *event);
-void notif_event_enque (struct notif_server *notif,
+void notif_event_enqueue (struct notif_server *notif,
 			struct notif_event *event);
 
 #endif /* GDBSERVER_NOTIF_H */
diff --git a/gdbserver/server.cc b/gdbserver/server.cc
index baccdf00172..0dedbff4047 100644
--- a/gdbserver/server.cc
+++ b/gdbserver/server.cc
@@ -188,7 +188,7 @@ queue_stop_reply (ptid_t ptid, const target_waitstatus &status)
   new_notif->ptid = ptid;
   new_notif->status = status;
 
-  notif_event_enque (&notif_stop, new_notif);
+  notif_event_enqueue (&notif_stop, new_notif);
 }
 
 static bool
@@ -3707,7 +3707,7 @@ queue_stop_reply_callback (thread_info *thread)
       new_notif->status = thread->last_status;
       /* Pass the last stop reply back to GDB, but don't notify
 	 yet.  */
-      notif_event_enque (&notif_stop, new_notif);
+      notif_event_enqueue (&notif_stop, new_notif);
     }
   else
     {

base-commit: 6926c5e74586d1eb64bfe586b15b630bfa8b0bd2
diff --git a/gdb/ada-lang.c b/gdb/ada-lang.c
index 564e4d6194a..b2e5367a147 100644
--- a/gdb/ada-lang.c
+++ b/gdb/ada-lang.c
@@ -462,7 +462,7 @@ field_name_match (const char *field_name, const char *target)
 }
 
 
 /* Assuming TYPE is a TYPE_CODE_STRUCT or a TYPE_CODE_TYPDEF to
    a TYPE_CODE_STRUCT, find the field whose name matches FIELD_NAME,
    and return its index.  This function also handles fields whose name
    have ___ suffixes because the compiler sometimes alters their name
@@ -8610,7 +8610,7 @@ ada_check_typedef (struct type *type)
 
   /* If our type is an access to an unconstrained array, which is encoded
      as a TYPE_CODE_TYPEDEF of a fat pointer, then we're done.
-     We don't want to strip the TYPE_CODE_TYPDEF layer, because this is
+     We don't want to strip the TYPE_CODE_TYPEDEF layer, because this is
      what allows us to distinguish between fat pointers that represent
      array types, and fat pointers that represent array access types
      (in both cases, the compiler implements them as fat pointers).  */
@@ -462,7 +462,7 @@ field_name_match (const char *field_name, const char *target)
 
 
-/* Assuming TYPE is a TYPE_CODE_STRUCT or a TYPE_CODE_TYPDEF to
+/* Assuming TYPE is a TYPE_CODE_STRUCT or a TYPE_CODE_TYPEDEF to
    a TYPE_CODE_STRUCT, find the field whose name matches FIELD_NAME,
    and return its index.  This function also handles fields whose name
-- 
2.51.0


^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2026-07-13 13:24 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2026-06-15 15:23 [PATCH] [gdb] More codespell fixes Tom de Vries
2026-07-13 13:23 ` Tom de Vries

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox